@@ -229,6 +229,7 @@ __all__ = (
     "GetVpnConnectionDeviceTypesPaginatorName",
     "HostRecoveryType",
     "HostTenancyType",
+    "HostnameTypeType",
     "HttpTokensStateType",
     "HypervisorTypeType",
     "IamInstanceProfileAssociationStateType",
@@ -743,6 +744,7 @@ GetTransitGatewayRouteTablePropagationsPaginatorName = Literal[
 GetVpnConnectionDeviceTypesPaginatorName = Literal["get_vpn_connection_device_types"]
 HostRecoveryType = Literal["off", "on"]
 HostTenancyType = Literal["dedicated", "host"]
+HostnameTypeType = Literal["ip-name", "resource-name"]
 HttpTokensStateType = Literal["optional", "required"]
 HypervisorTypeType = Literal["ovm", "xen"]
 IamInstanceProfileAssociationStateType = Literal[
@@ -1572,6 +1574,7 @@ ServiceName = Literal[
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -1640,6 +1643,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
